@@ -3,7 +3,7 @@
 #' Coercing \code{trip} objects to other classes.
 #'
 #' @name as.Other
-#' @aliases  as.psp.trip as.track_xyt.trip
+#' @aliases  as.psp.trip as.track_xyt.trip as.ppp as.psp
 # section Methods:
 #
 # ##\describe{
@@ -23,7 +23,7 @@ setAs("trip", "SpatialLinesDataFrame", function(from) {
                       ID=sdf$tripID[i])
   }
   SpatialLinesDataFrame(SpatialLines(lns,
-                                     proj4string=CRS(proj4string(from))),
+                                     proj4string=CRS(from@proj4string@projargs, doCheckCRSArgs=FALSE)),
                         df)
 })
 
@@ -66,6 +66,7 @@ setAs("trip", "ltraj", function(from) {
 
 ## @importClassesFrom maptools owin ppp psp
 #' @importFrom spatstat as.ppp
+#' @export as.ppp
 #' @importFrom maptools as.ppp.SpatialPointsDataFrame
 #' @param X \code{trip} object.
 #' @param fatal Logical value, see Details of \code{\link[spatstat]{as.ppp}}
@@ -77,7 +78,7 @@ setAs("trip", "ltraj", function(from) {
 #'  d <- data.frame(x=1:10, y=rnorm(10), tms=Sys.time() + 1:10, id=gl(2, 5))
 #' sp::coordinates(d) <- ~x+y
 #' ## this avoids complaints later, but these are not real track data (!)
-#' sp::proj4string(d) <- sp::CRS("+proj=laea +ellps=sphere")
+#' sp::proj4string(d) <- sp::CRS("+proj=laea +ellps=sphere",  doCheckCRSArgs = FALSE)
 #' tr <- trip(d, c("tms", "id"))
 #' 
 #'  as(tr, "ppp")
@@ -89,6 +90,7 @@ setAs("trip", "ppp", function(from) as.ppp.trip(from))
 
 #' @export
 #' @importFrom spatstat as.psp owin psp superimpose
+#' @export as.psp
 #' @param x \code{trip} object
 #' @param from see \code{\link[spatstat]{as.psp}} for that method.
 #' @param to See \code{\link[spatstat]{as.psp}}.
@@ -100,25 +102,27 @@ setAs("trip", "ppp", function(from) as.ppp.trip(from))
 #'  d <- data.frame(x=1:10, y=rnorm(10), tms=Sys.time() + 1:10, id=gl(2, 5))
 #' sp::coordinates(d) <- ~x+y
 #' ## this avoids complaints later, but these are not real track data (!)
-#' sp::proj4string(d) <- sp::CRS("+proj=laea +ellps=sphere")
+#' sp::proj4string(d) <- sp::CRS("+proj=laea +ellps=sphere", doCheckCRSArgs = FALSE)
 #' tr <- trip(d, c("tms", "id"))
 #' 
 #'  as.psp.trip(tr)
 #' }
 as.psp.trip <- function(x, ..., from, to) {
-  split.X <- split(x, x[[getTORnames(x)[2]]])
-  ow <- owin(bbox(x)[1,], bbox(x)[2,])
-  as.psp.trip1 <- function(this, ow=NULL) {
-    if (is.null(ow)) ow <- owin(bbox(this)[1,], bbox(this)[2,])
-    tor <- getTORnames(this)
+  tor <- getTORnames(x)
+  split.X <- split(x, x[[tor[2L]]])
+  bb <- bbox(x)
+  ow <- owin(bb[1L,], bb[2L,])
+  as.psp.trip1 <- function(this) {
+    #if (is.null(ow)) ow <- owin(bbox(this)[1,], bbox(this)[2,])
+    #tor <- getTORnames(this)
     cc <- coordinates(this)
-    xs <- coordinates(this)[, 1]
-    ys <- coordinates(this)[, 2]
-    dt <- diff(unclass(this[[tor[1]]]))
+    xs <- cc[, 1L]
+    ys <- cc[, 2L]
+    dt <- diff(unclass(this[[tor[1L]]]))
     psp(xs[-length(xs)], ys[-length(ys)],
-        xs[-1], ys[-1], window=ow, marks=dt)
+        xs[-1L], ys[-1L], window=ow, marks=dt)
   }
-  do.call("superimpose", lapply(split.X, as.psp.trip1, ow=ow))
+  do.call("superimpose", lapply(split.X, as.psp.trip1))
 }
 setAs("trip", "psp", function(from) as.psp.trip(from))
 
@@ -150,7 +154,7 @@ setAs("trip", "track_xyt", function(from) as.track_xyt.trip(from))
 #'  d <- data.frame(x=1:10, y=rnorm(10), tms=Sys.time() + 1:10, id=gl(2, 5))
 #' sp::coordinates(d) <- ~x+y
 #' ## this avoids complaints later, but these are not real track data (!)
-#' sp::proj4string(d) <- sp::CRS("+proj=laea +ellps=sphere")
+#' sp::proj4string(d) <- sp::CRS("+proj=laea +ellps=sphere", doCheckCRSArgs = FALSE)
 #' tr <- trip(d, c("tms", "id"))
 #' 
 #' spldf <- explode(tr)
@@ -181,7 +185,7 @@ explode <- function(x, ...) {
     }
 
   }
-  splines <- SpatialLines(Linelist, proj4string = CRS(proj4string(x)))
+  splines <- SpatialLines(Linelist, proj4string = CRS(x@proj4string@projargs, doCheckCRSArgs = FALSE))
   SpatialLinesDataFrame(splines, df)
 }
 
