@@ -1,36 +1,36 @@
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(trip)
 d <- data.frame(x=1:10,y=rnorm(10), tms=Sys.time() + 1:10, id=gl(2, 5))
 tr <- trip(d)
 summary(tr)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 plot(tr)
 lines(tr)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 plot(tr,pch = ".", col = rainbow(nrow(tr)))
 lines(tr, col = c("dodgerblue", "firebrick"))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tg <- rasterize(tr)
 plot(tg, col = c("transparent", heat.colors(25)))
 
-## ----read-argos----------------------------------------------------------
+## ----read-argos---------------------------------------------------------------
 argosfile <- 
  system.file("extdata/argos/98feb.dat", package = "trip", mustWork = TRUE)
 argos <- readArgos(argosfile) 
 
 summary(argos)
 
-## ----plot-argos-anti-meridian--------------------------------------------
+## ----plot-argos-anti-meridian-------------------------------------------------
 plot(argos, pch = ".")
 lines(argos)
 maps::map("world2", add = TRUE)
 axis(1)
 sp::degAxis(2)
 
-## ----destructive-filters-------------------------------------------------
+## ----destructive-filters------------------------------------------------------
 argos$spd <- speedfilter(argos, max.speed = 4)  ## km/h
 mean(argos$spd)  ## more than 5% are too fast
 
@@ -44,7 +44,7 @@ plot(argos)
 lines(argos[argos$sda, ])
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 raster::projection(walrus818)
 data("walrus818")
 
@@ -54,31 +54,29 @@ lines(walrus818)
 axis(1)
 axis(2)
 
-## ------------------------------------------------------------------------
-library(maptools)
-library(rgdal)
-data(wrld_simpl)
-world <- sp::spTransform(subset(wrld_simpl, coordinates(wrld_simpl)[,2] > 0), proj4string(walrus818))
+## -----------------------------------------------------------------------------
+data("world_north", package= "trip")
 p <- par(mar = rep(0.5, 4))
 plot(raster::extent(walrus818) + 600000)
 plot(walrus818, pch = ".", add = TRUE)
-plot(world, add = TRUE, col = "grey")
+plot(world_north, add = TRUE, col = "grey")
 lines(walrus818)
-llgridlines(walrus818); par(p)
+par(p)
 
-## ----conversions-points--------------------------------------------------
+## ----conversions-points-------------------------------------------------------
 ## as points
 as(walrus818, "SpatialPointsDataFrame")
 as(walrus818, "ppp")
 
 
-## ----conversions-lines---------------------------------------------------
+## ----conversions-lines--------------------------------------------------------
 ## as lines
 as(walrus818, "SpatialLinesDataFrame")
-as(walrus818, "sf")
+class(as(walrus818, "sf"))
+class(as(walrus818, "sf")$geom)
 as(walrus818, "ltraj")
 
-## ----conversions-segments------------------------------------------------
+## ----conversions-segments-----------------------------------------------------
 ## as segments
 explode(walrus818)
 as(walrus818, "psp")
